require_relative 'player'
require_relative 'game_turn'
require_relative 'treasure_trove'
module StudioGame
  class Game

    attr_accessor :title

    def initialize(title)
      @title = title
      @players = []
    end

    def save_high_scores(to_file="high_scores.txt")
      File.open(to_file, "w") do |file|
        file.puts "#{@title} High Scores:"
        @players.sort.each do |player|
          file.puts high_score_entry(player)
        end
      end
    end

    def high_score_entry(player)
      formatted_name = player.name.ljust(20, '.')
      puts "#{formatted_name} #{player.score}"
    end

    def load_players(from_file)
      File.readlines(from_file).each do |line|
        add_player(Player.from_csv(line))
      end
    end

    def add_player(a_player)
      @players.push(a_player)
    end

    def play(rounds)
      treasures = TreasureTrove::TREASURES
      puts "There are #{treasures.size} treasures to be found"
      treasures.each do |r| puts "#{r.name} is worth #{r.points} points"
      end

      puts "There are #{@players.size} players in #{@title}: "

      @players.each do |player|
        puts player
      end

      1.upto(rounds) do |r|
        puts "Round #{r}"
        @players.each do |player|
          GameTurn.take_turn(player)
          puts player
        end
      end
    end

    def print_name_and_health(player)
      puts "#{player.name}, #{player.health}"
    end

    def print_stats
      puts "#{@title} Stats"

      strong,wimpy = @players.partition do |s| s.strong? end

      puts "#{strong.length} Strong Players:"
      strong.each do |d|
        print_name_and_health(d)
      end

      puts "#{wimpy.length} Wimpy Players:"
      wimpy.each do |d|
        print_name_and_health(d)
      end

      puts "#{@title} High Scores"
      @players.sort.each do |player|
        puts high_score_entry(player)
      end

      @players.each {
        |s| puts "#{s.name} has #{s.points}"
      }
      @players.sort.each do |x|
        puts "#{x.name} has #{x.points}"
        x.each_found_treasure do |y|
          puts "#{y.points} total #{y.name} points"
        end
      puts "#{x.points} total points"
      end
    end

  end
end
